import { sharedComposables } from './composables';
import type { IGoogleMapsApiObject, IPluginOptions } from './interfaces';
import type { GlobalGoogleObject, GmvComponents, GmvUtilities } from './types';
import type { Emitter, EventType } from 'mitt';
import type { Plugin } from 'vue';
/**
 * Vue augmentations
 */
declare module 'vue' {
    interface ComponentCustomProperties {
        $gmapDefaultResizeBus: Emitter<Record<EventType, unknown>>;
        $gmapApiPromiseLazy: () => Promise<any>;
        $gmapOptions: IPluginOptions;
    }
}
declare global {
    var GoogleMapsApi: IGoogleMapsApiObject;
    var GoogleMapsCallback: () => void;
    interface Window {
        GoogleMapsApi: IGoogleMapsApiObject;
        GoogleMapsCallback: <T = unknown>() => T;
        google: GlobalGoogleObject;
        [key: string | number | symbol]: any;
    }
}
/**
 * Export all components
 * @constant
 * @type  {Object} components object
 * @property  {Object}  HeatmapLayer - Vue component HeatmapLayer
 * @property  {Object}  KmlLayer - Vue component KmlLayer
 * @property  {Object}  Marker - Vue component Marker
 * @property  {Object}  Polyline - Vue component Polyline
 * @property  {Object}  Polygon - Vue component Polygon
 * @property  {Object}  Circle - Vue component Circle
 * @property  {Object}  Cluster - Vue component Cluster
 * @property  {Object}  Rectangle - Vue component Rectangle
 * @property  {Object}  DrawingManager - Vue component DrawingManager
 * @property  {Object}  InfoWindow - Vue component InfoWindow
 * @property  {Object}  MapLayer - Vue component MapLayer
 * @property  {Object}  PlaceInput - Vue component PlaceInput
 * @property  {Object}  Autocomplete - Vue component Autocomplete
 * @property  {Object}  StreetViewPanorama - Vue component StreetViewPanorama
 */
declare const components: GmvComponents;
/**
 * Export all utilities
 *
 * @constant
 * @type  {Object} object containing all utilities
 * @property  {Function}  googleMapsApiInitializer - function to initialize the Google Maps API
 * @property  {Function}  pluginComponentBuilder - function to initialize the Google Maps API
 * @property  {Function}  getGoogleMapsAPI - function to get the original Google Maps API
 */
declare const utilities: GmvUtilities;
/**
 * Export the default Vue object for plugins
 * Export for ESM modules
 *
 * @see pluginInstallFn
 * @type GmapVue
 * @property {Function} install function to install the plugin
 */
declare const GmapVuePlugin: Plugin;
export { GmapVuePlugin, components, sharedComposables as composables, utilities, };
